@@ -21,16 +21,25 @@ def print_message(message: str, timer_val: int = None):
         print(
             f"{Fore.BLUE}Press ENTER to stop timer.{Style.RESET_ALL}",
         )
+    elif message == "show_insights":
+        print(f"\n{Fore.BLUE}Press ENTER to return to main menu{Style.RESET_ALL}")
+    elif message == "bar_header":
+        print(f"{Fore.YELLOW}Weekly minutes{Style.RESET_ALL}")
+    elif message == "heat_header":
+        print(f"{Fore.YELLOW}Work heatmap{Style.RESET_ALL}")
+    elif message == "cursor":
+        return f"{Fore.MAGENTA}>> {Style.RESET_ALL}"
 
 
 def options():
     return """Additional commands;
 S       --    Swap upcoming timer
+I       --    Show the insights tab
 Q       --    Quit SYLO
 """
 
 
-def print_update(durations: Durations, mode: str, show_options: bool = False):
+def print_update(durations: Durations, mode: str, show_options: bool = False, show_graphs: bool = False):
     logger.debug(f'Printing update: {mode} with show_options {show_options}')
     if mode == 'rest':
         upcoming_timer_color = durations.rest.bar_color
@@ -41,16 +50,20 @@ def print_update(durations: Durations, mode: str, show_options: bool = False):
         print_ops = options()
     else:
         print_ops = '.. or chose an optional command (H for help)'
+
     print(
         f"""
 Work length:        {Fore.RED}{durations.work.mins} minutes{Style.RESET_ALL}
 Rest length:        {Fore.GREEN}{durations.rest.mins} minutes{Style.RESET_ALL}
-Total work time:    {Fore.YELLOW}{durations.total_mins} minutes{Style.RESET_ALL}
+Total work time:    {Fore.YELLOW}{int(durations.total_work_mins)} minutes{Style.RESET_ALL}
+Total rest time:    {Fore.YELLOW}{int(durations.total_rest_mins)} minutes{Style.RESET_ALL}
+
 Upcoming timer:     {upcoming_timer_color}{mode.upper()}{Style.RESET_ALL}
 
 {Fore.BLUE}Press {Style.RESET_ALL}{Fore.YELLOW}ENTER {Style.RESET_ALL}{Fore.BLUE}to start the next timer{Style.RESET_ALL}
 
 {Fore.BLUE}{print_ops}{Style.RESET_ALL}
+
     """)
 
 
@@ -64,10 +77,10 @@ def print_header_small(double: bool):
     else:
         font = ascii_header_small(font='alligator')
     if double is True:
-        color = Fore.BLUE
+        color = Fore.RED
         double_message = '>>>>>>>>>>>> DOUBLE SPEED MODE >>>>>>>>>>>>'
     else:
-        color = Fore.RED
+        color = Fore.BLUE
         double_message = ''
     print(f"{double_message}")
     print(f"""{color}{font}{Style.RESET_ALL}""")
