@@ -11,21 +11,33 @@ from sylo.messages import (
     print_update,
     print_header_small,
 )
-from sylo.models import Durations
+from sylo.models import Durations, DataPersistence
 from sylo.definitions import (
     WELCOME_CHOICES,
     COUNTDOWN_INCREMENTS,
+    DATA_FILE_LOCATION,
+    METRICS_BAR,
+    METRICS_HEAT,
+    DATA_FILE_CREATE,
+    HOME_DIR_CREATE,
+    ONE_WEEK_AGO,
+    ONE_YEAR_AGO,
 )
 from sylo.utils import (
     clear_screen,
     mins_to_secs,
     flip_mode,
+    get_input,
+    run_subprocess,
+    check_for_file,
 )
 
 logger = logging.getLogger(__name__)
 
 is_double = False
 timer_mode = 'work'
+data_file = DataPersistence()
+cursor = print_message('cursor')
 
 
 class Timer:
@@ -33,6 +45,7 @@ class Timer:
         self.durations = durations
         self.mode: str = mode
         self.increments = increments
+        self.mins_passed = 0
 
         if self.mode == "work":
             self.mins = self.durations.work.mins
@@ -43,7 +56,7 @@ class Timer:
             self.secs = self.durations.rest.secs
             self.bar_color = self.durations.rest.bar_color
 
-    def start_timer(self):
+    def _start_timer(self):
         timer_iterator = tqdm(
             total=self.secs,
             position=0,
@@ -60,20 +73,21 @@ class Timer:
                 self.secs -= self.increments
                 timer_iterator.update(self.increments)
                 if self.secs % 60 == 0:
+                    self.mins_passed += 1
                     logger.debug(f'{self.mode} Timer loop: secs remaining: {self.secs}')
         except KeyboardInterrupt:
             print('\nQuitting early..')
             logger.info(f'Ctrl-C quit with {self.secs} remaining')
-            return False
+            return False, self.mins_passed
             pass
         logger.info(f'{self.mode} timer loop finished')
         timer_iterator.close()
-        return True
+        return True, self.mins_passed
 
     def start_countdown(self):
         logger.info(f'{self.mode} timer started')
-        hard_quit = self.start_timer()
-        return hard_quit
+        complete, mins_passed = self._start_timer()
+        return complete, mins_passed
 
 
 class Sound:
@@ -106,6 +120,30 @@ class Sound:
             beep("ready")
 
 
+class Insights:
+
+    def __init__(self):
+        self.data_file = DATA_FILE_LOCATION
+        self.heatmap_start_date = ONE_YEAR_AGO
+        self.bar_start_date = ONE_WEEK_AGO
+
+    def print_bar(self):
+        logger.info(f'Running ${self._bar_chart()}')
+        print_message('bar_header')
+        run_subprocess(self._bar_chart())
+
+    def print_heat(self):
+        logger.info(f'Running ${self._heat_map()}')
+        print_message('heat_header')
+        run_subprocess(self._heat_map())
+
+    def _bar_chart(self):
+        return METRICS_BAR % (self.data_file, self.bar_start_date)
+
+    def _heat_map(self):
+        return METRICS_HEAT % (self.heatmap_start_date, self.data_file)
+
+
 def sylo(
         durations_model: Durations,
         sound_obj: any,
@@ -113,13 +151,7 @@ def sylo(
         show_options: bool,
         double: bool = is_double,
 ):
-    logger.info(f'Running sylo in {mode} mode')
-    logger.info(f'Running sylo with show_options set to {show_options}')
-    logger.info(f'Running sylo with double set to {double}')
-    logger.info(f'Running sylo with total mins set to {durations_model.total_mins}')
-
     clear_screen()
-
     if double is True:
         increments = 30
     else:
@@ -131,7 +163,7 @@ def sylo(
 
     print_update(timer.durations, mode, show_options)
 
-    response = input("> ")
+    response = get_input(cursor)
     logger.info(f'User response: {response}')
 
     while response.lower() not in WELCOME_CHOICES:
@@ -148,6 +180,20 @@ def sylo(
         logger.info('Quit requested')
         clear_screen()
         sys.exit()
+    while response.lower() == "i":
+        clear_screen()
+        metrics = Insights()
+        metrics.print_bar()
+        metrics.print_heat()
+        print_message('show_insights')
+        input(cursor)
+        sylo(
+            durations_model=durations_model,
+            sound_obj=sound_obj,
+            mode=mode,
+            show_options=show_options,
+            double=double,
+        )
     while response.lower() == "s":
         logger.info('Switch requested')
         new_mode = flip_mode(mode)
@@ -171,17 +217,28 @@ def sylo(
     while response == "":
         logger.info('User pressed ENTER')
         if mode == 'rest':
-            complete = timer.start_countdown()
+            complete, secs_passed = timer.start_countdown()
             if complete is True:
                 sound_obj.play_sound()
+                durations_model.total_rest_mins += secs_passed
+            else:
+                durations_model.total_rest_mins += secs_passed
             next_mode = flip_mode(mode)
+            data_file.data_refresh(durations_model)
+            clear_screen()
         else:
-            complete = timer.start_countdown()
+            complete, secs_passed = timer.start_countdown()
             if complete is True:
                 sound_obj.play_sound()
-                durations_model.total_mins += durations_model.work.mins
+                durations_model.total_work_mins += durations_model.work.mins
+            else:
+                durations_model.total_work_mins += secs_passed
             next_mode = flip_mode(mode)
-
+            data_file.data_refresh(durations_model)
+            clear_screen()
+        logger.info('Durations model set')
+        logger.info(f'Work time: {durations_model.total_work_mins}')
+        logger.info(f'Work time: {durations_model.total_rest_mins}')
         sylo(
             durations_model=durations_model,
             sound_obj=sound_obj,
@@ -192,10 +249,16 @@ def sylo(
 
 
 def run(args):
+
+    if check_for_file(DATA_FILE_LOCATION) is False:
+        logger.info(f'No data file found, creating at {DATA_FILE_LOCATION}')
+        run_subprocess(HOME_DIR_CREATE)
+        run_subprocess(DATA_FILE_CREATE)
     global is_double, timer_mode
     clear_screen()
 
     durations_data = Durations()
+    data_file.data_load_on_boot(durations_data)
 
     if args.work_time:
         durations_data.work.mins = args.work_time
